package com.huawei.demo;

import com.huawei.demo.common.logger.DefaultLogger;
import com.huawei.demo.model.AccessPointPara;
import com.huawei.demo.model.FunctionGraphPara;
import com.huawei.demo.model.TdpFuncResult;
import com.huawei.services.runtime.Context;

import java.util.Optional;

/**
 * 实现该类。
 * WARNING：{@link #apiHandle(FunctionGraphPara, Context)} 该方法必须在子类中定义，否则函数无法触发该函数接口！！！
 * <pre>
 * {@code
 *     @Override
 *     public TdpFuncResult apiHandle(FunctionGraphPara para, Context context) {
 *         return super.apiHandle(para, context);
 *     }
 * }
 * </pre>
 */
public abstract class TdpFunction {
    protected static final DefaultLogger LOGGER = new DefaultLogger(TdpFunction.class);
    protected Context context;

    /**
     * 函数定义
     */
    public TdpFuncResult apiHandle(FunctionGraphPara para, Context context) {
        // 获取日志
        DefaultLogger.init(Optional.ofNullable(context)
            .map(Context::getLogger)
            .orElse(null));
        this.context = context;

        // 校验入参
        TdpFuncResult result = checkPara(para, context);
        if (result != null) {
            return result;
        }

        // 确定接入点
        AccessPointPara accessPointPara = determineAccessPoint(para);

        // 发放设备
        result = provisionDevice(para, accessPointPara);

        LOGGER.info("result:{}", result);
        return result;
    }

    /**
     * 校验入参
     */
    protected abstract TdpFuncResult checkPara(FunctionGraphPara para, Context context);

    /**
     * 从备选的接入点中选择合适的接入点
     */
    protected abstract AccessPointPara determineAccessPoint(FunctionGraphPara para);

    /**
     * 调用设备发放的发放接口发放设备
     */
    protected abstract TdpFuncResult provisionDevice(FunctionGraphPara para, AccessPointPara accessPointPara);
}
