package com.huawei.demo.api;

import okhttp3.OkHttpClient;
import okhttp3.Protocol;

import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.TrustManager;
import javax.net.ssl.X509TrustManager;

import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.security.cert.X509Certificate;
import java.util.Collections;
import java.util.concurrent.TimeUnit;

/**
 * 基于okhttp库的rest client 工程
 */
public class OkHttpClientFactory {
    private OkHttpClientFactory() {
        throw new UnsupportedOperationException();
    }

    /**
     * 设置服务端响应超时时间为30s
     */
    private static final OkHttpClient CLIENT = new OkHttpClient.Builder()
        .retryOnConnectionFailure(true)
        .callTimeout(30, TimeUnit.SECONDS)
        .readTimeout(30, TimeUnit.SECONDS)
        .sslSocketFactory(getSocketFactory(), (X509TrustManager) getTrustManager())
        .hostnameVerifier((s, sslSession) -> true)
        .protocols(Collections.singletonList(Protocol.HTTP_1_1))
        .build();

    public static OkHttpClient getOkHttpClient() {
        return CLIENT;
    }

    private static TrustManager getTrustManager() {
        return new X509TrustManager() {
            @Override
            public void checkClientTrusted(X509Certificate[] chain, String authType) {
            }

            @Override
            public void checkServerTrusted(X509Certificate[] chain, String authType) {
            }

            @Override
            public X509Certificate[] getAcceptedIssuers() {
                return new X509Certificate[0];
            }
        };
    }

    private static SSLSocketFactory getSocketFactory() {
        SSLContext sslContext = null;
        try {
            sslContext = SSLContext.getInstance("SSL");
            sslContext.init(null, new TrustManager[] {getTrustManager()}, new SecureRandom());
        } catch (NoSuchAlgorithmException | KeyManagementException e) {
            //log.warn("get ssl context failed, exception = {}", e.getLocalizedMessage());
        }

        if (null != sslContext) {
            return sslContext.getSocketFactory();
        }

        //log.warn("get ssl context is null.");
        return null;
    }
}
