package com.huawei.demo.common.utils;

public class ExceptionUtil {
    /**
     * 换行符
     */
    private static final String LINE_SEPARATOR = "\r\n";

    /**
     * 获取指定行数的异常堆栈信息
     *
     * @param e       异常
     * @param lineNum 要打印的堆栈行数
     */
    public static String getExceptionStackTrace(Throwable e, int lineNum) {
        if (e == null) {
            return "";
        }
        String message = e.toString();
        StringBuilder stackTrace;
        if (message.length() > 256) {
            stackTrace = new StringBuilder(message.substring(0, 255));
        } else {
            stackTrace = new StringBuilder(message);
        }
        StackTraceElement[] aStackTraceElement = e.getStackTrace();
        int size = Math.min(lineNum, aStackTraceElement.length);

        for (int i = 0; i < size; i++) {
            stackTrace.append(LINE_SEPARATOR).append("\tat ");

            if (aStackTraceElement[i].toString().length() > 256) {
                stackTrace.append(aStackTraceElement[i].toString().substring(0, 255));
            } else {
                stackTrace.append(aStackTraceElement[i].toString());
            }
        }

        return stackTrace.toString();
    }

    /**
     * 获取简洁的异常堆栈，只打印最后五个调用堆栈
     */
    public static String getBriefExceptionStackTrace(Throwable e) {
        return getExceptionStackTrace(e, 5);
    }
}
