package com.huawei.demo.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.util.Objects;
import java.util.function.Consumer;

/**
 * 使用自定义策略的设备上电后触发引导发放流程，服务携带该结构体参数回调用户在函数服务自定义的函数。
 */
public class AuthInfoPara {

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "authType")
    private String authType;

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "secret")
    @JsonIgnore
    private String secret;

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "certInfo")

    private CertInfoPara certInfo = null;

    public AuthInfoPara withAuthType(String authType) {
        this.authType = authType;
        return this;
    }

    /**
     * 认证类型。  可选 SECRET 和 CERTIFICATES。
     *
     * @return authType
     */
    public String getAuthType() {
        return authType;
    }

    public void setAuthType(String authType) {
        this.authType = authType;
    }

    public AuthInfoPara withSecret(String secret) {
        this.secret = secret;
        return this;
    }

    /**
     * 当 authType 为 SECRET 时，返回密钥信息。
     *
     * @return secret
     */
    public String getSecret() {
        return secret;
    }

    public void setSecret(String secret) {
        this.secret = secret;
    }

    public AuthInfoPara withCertInfo(CertInfoPara certInfo) {
        this.certInfo = certInfo;
        return this;
    }

    public AuthInfoPara withCertInfo(Consumer<CertInfoPara> certInfoSetter) {
        if (this.certInfo == null) {
            this.certInfo = new CertInfoPara();
            certInfoSetter.accept(this.certInfo);
        }

        return this;
    }

    /**
     * Get certInfo
     *
     * @return certInfo
     */
    public CertInfoPara getCertInfo() {
        return certInfo;
    }

    public void setCertInfo(CertInfoPara certInfo) {
        this.certInfo = certInfo;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthInfoPara authInfoPara = (AuthInfoPara) o;
        return Objects.equals(this.authType, authInfoPara.authType) &&
            Objects.equals(this.secret, authInfoPara.secret) &&
            Objects.equals(this.certInfo, authInfoPara.certInfo);
    }

    @Override
    public int hashCode() {
        return Objects.hash(authType, secret, certInfo);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthInfoPara {\n");
        sb.append("    authType: ").append(toIndentedString(authType)).append("\n");
        sb.append("    secret: ").append(toIndentedString("******")).append("\n");
        sb.append("    certInfo: ").append(toIndentedString(certInfo)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

