package com.huawei.demo.model;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.util.Objects;

/**
 * DeviceCertPara
 */
public class DeviceCertPara {

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "subjectCnName")
    private String subjectCnName;

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "issuerCnName")
    private String issuerCnName;

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "sha1Fingerprint")
    private String sha1Fingerprint;

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "sha256Fingerprint")
    private String sha256Fingerprint;

    public DeviceCertPara withSubjectCnName(String subjectCnName) {
        this.subjectCnName = subjectCnName;
        return this;
    }

    /**
     * 证书使用者CN NAME。
     *
     * @return subjectCnName
     */
    public String getSubjectCnName() {
        return subjectCnName;
    }

    public void setSubjectCnName(String subjectCnName) {
        this.subjectCnName = subjectCnName;
    }

    public DeviceCertPara withIssuerCnName(String issuerCnName) {
        this.issuerCnName = issuerCnName;
        return this;
    }

    /**
     * 证书颁发者CN NAME。
     *
     * @return issuerCnName
     */
    public String getIssuerCnName() {
        return issuerCnName;
    }

    public void setIssuerCnName(String issuerCnName) {
        this.issuerCnName = issuerCnName;
    }

    public DeviceCertPara withSha1Fingerprint(String sha1Fingerprint) {
        this.sha1Fingerprint = sha1Fingerprint;
        return this;
    }

    /**
     * 证书指纹（使用SHA-1算法计算）。
     *
     * @return sha1Fingerprint
     */
    public String getSha1Fingerprint() {
        return sha1Fingerprint;
    }

    public void setSha1Fingerprint(String sha1Fingerprint) {
        this.sha1Fingerprint = sha1Fingerprint;
    }

    public DeviceCertPara withSha256Fingerprint(String sha256Fingerprint) {
        this.sha256Fingerprint = sha256Fingerprint;
        return this;
    }

    /**
     * 证书指纹（使用SHA-256算法计算）。
     *
     * @return sha256Fingerprint
     */
    public String getSha256Fingerprint() {
        return sha256Fingerprint;
    }

    public void setSha256Fingerprint(String sha256Fingerprint) {
        this.sha256Fingerprint = sha256Fingerprint;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DeviceCertPara deviceCertPara = (DeviceCertPara) o;
        return Objects.equals(this.subjectCnName, deviceCertPara.subjectCnName) &&
            Objects.equals(this.issuerCnName, deviceCertPara.issuerCnName) &&
            Objects.equals(this.sha1Fingerprint, deviceCertPara.sha1Fingerprint) &&
            Objects.equals(this.sha256Fingerprint, deviceCertPara.sha256Fingerprint);
    }

    @Override
    public int hashCode() {
        return Objects.hash(subjectCnName, issuerCnName, sha1Fingerprint, sha256Fingerprint);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DeviceCertPara {\n");
        sb.append("    subjectCnName: ").append(toIndentedString(subjectCnName)).append("\n");
        sb.append("    issuerCnName: ").append(toIndentedString(issuerCnName)).append("\n");
        sb.append("    sha1Fingerprint: ").append(toIndentedString(sha1Fingerprint)).append("\n");
        sb.append("    sha256Fingerprint: ").append(toIndentedString(sha256Fingerprint)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

