package com.huawei.demo.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.function.Consumer;

/**
 * 使用自定义策略的设备上电后触发引导发放流程，服务携带该结构体参数回调用户在函数服务自定义的函数。
 */
public class FunctionGraphPara {

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "iamToken")
    @JsonIgnore
    private String iamToken;

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "deviceId")
    private String deviceId;

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "deviceName")
    private String deviceName;

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "accessPoints")
    private List<AccessPointPara> accessPoints = null;

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "authInfo")
    private AuthInfoPara authInfo = null;

    public FunctionGraphPara withIamToken(String iamToken) {
        this.iamToken = iamToken;
        return this;
    }

    /**
     * 用户Token。  通过调用IAM服务获取用户Token接口获取（响应消息头中X-Subject-Token的值）。
     *
     * @return iamToken
     */
    public String getIamToken() {
        return iamToken;
    }

    public void setIamToken(String iamToken) {
        this.iamToken = iamToken;
    }

    public FunctionGraphPara withDeviceId(String deviceId) {
        this.deviceId = deviceId;
        return this;
    }

    /**
     * 设备id
     *
     * @return deviceId
     */
    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public FunctionGraphPara withDeviceName(String deviceName) {
        this.deviceName = deviceName;
        return this;
    }

    /**
     * 设备名称。
     *
     * @return deviceName
     */
    public String getDeviceName() {
        return deviceName;
    }

    public void setDeviceName(String deviceName) {
        this.deviceName = deviceName;
    }

    public FunctionGraphPara withAccessPoints(List<AccessPointPara> accessPoints) {
        this.accessPoints = accessPoints;
        return this;
    }

    public FunctionGraphPara addAccessPointsItem(AccessPointPara accessPointsItem) {
        if (this.accessPoints == null) {
            this.accessPoints = new ArrayList<>();
        }
        this.accessPoints.add(accessPointsItem);
        return this;
    }

    public FunctionGraphPara withAccessPoints(Consumer<List<AccessPointPara>> accessPointsSetter) {
        if (this.accessPoints == null) {
            this.accessPoints = new ArrayList<>();
        }
        accessPointsSetter.accept(this.accessPoints);
        return this;
    }

    /**
     * Get accessPoints
     *
     * @return accessPoints
     */
    public List<AccessPointPara> getAccessPoints() {
        return accessPoints;
    }

    public void setAccessPoints(List<AccessPointPara> accessPoints) {
        this.accessPoints = accessPoints;
    }

    public FunctionGraphPara withAuthInfo(AuthInfoPara authInfo) {
        this.authInfo = authInfo;
        return this;
    }

    public FunctionGraphPara withAuthInfo(Consumer<AuthInfoPara> authInfoSetter) {
        if (this.authInfo == null) {
            this.authInfo = new AuthInfoPara();
            authInfoSetter.accept(this.authInfo);
        }

        return this;
    }

    /**
     * Get authInfo
     *
     * @return authInfo
     */
    public AuthInfoPara getAuthInfo() {
        return authInfo;
    }

    public void setAuthInfo(AuthInfoPara authInfo) {
        this.authInfo = authInfo;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        FunctionGraphPara functionGraphPara = (FunctionGraphPara) o;
        return Objects.equals(this.iamToken, functionGraphPara.iamToken) &&
            Objects.equals(this.deviceId, functionGraphPara.deviceId) &&
            Objects.equals(this.deviceName, functionGraphPara.deviceName) &&
            Objects.equals(this.accessPoints, functionGraphPara.accessPoints) &&
            Objects.equals(this.authInfo, functionGraphPara.authInfo);
    }

    @Override
    public int hashCode() {
        return Objects.hash(iamToken, deviceId, deviceName, accessPoints, authInfo);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class FunctionGraphPara {\n");
        sb.append("    iamToken: ").append(toIndentedString("******")).append("\n");
        sb.append("    deviceId: ").append(toIndentedString(deviceId)).append("\n");
        sb.append("    deviceName: ").append(toIndentedString(deviceName)).append("\n");
        sb.append("    secret: ").append(toIndentedString("******")).append("\n");
        sb.append("    accessPoints: ").append(toIndentedString(accessPoints)).append("\n");
        sb.append("    authInfo: ").append(toIndentedString(authInfo)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

