package com.huawei.demo.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonValue;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import java.util.function.Consumer;

/**
 * TdpFuncBody
 */
public class TdpFuncBody {

    /**
     * 设备发放业务功能标识，allow表示发放成功，deny表示发放失败，设备发放使用此标识判断函数内业务功能执行与否
     */
    public static final class StatusEnum {

        /**
         * Enum ALLOW for value: "allow"
         */
        public static final StatusEnum ALLOW = new StatusEnum("allow");

        /**
         * Enum DENY for value: "deny"
         */
        public static final StatusEnum DENY = new StatusEnum("deny");

        private static final Map<String, StatusEnum> STATIC_FIELDS = createStaticFields();

        private static Map<String, StatusEnum> createStaticFields() {
            Map<String, StatusEnum> map = new HashMap<>();
            map.put("allow", ALLOW);
            map.put("deny", DENY);
            return Collections.unmodifiableMap(map);
        }

        private String value;

        StatusEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return String.valueOf(value);
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static StatusEnum fromValue(String value) {
            if (value == null) {
                return null;
            }
            StatusEnum result = STATIC_FIELDS.get(value);
            if (result == null) {
                result = new StatusEnum(value);
            }
            return result;
        }

        public static StatusEnum valueOf(String value) {
            if (value == null) {
                return null;
            }
            StatusEnum result = STATIC_FIELDS.get(value);
            if (result != null) {
                return result;
            }
            throw new IllegalArgumentException("Unexpected value '" + value + "'");
        }

        @Override
        public boolean equals(Object obj) {
            if (obj != null && obj instanceof StatusEnum) {
                return this.value.equals(((StatusEnum) obj).value);
            }
            return false;
        }

        @Override
        public int hashCode() {
            return this.value.hashCode();
        }
    }

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "status")

    private StatusEnum status = StatusEnum.ALLOW;

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "context")

    private TdpFuncBodyContext context = null;

    public TdpFuncBody withStatus(StatusEnum status) {
        this.status = status;
        return this;
    }

    /**
     * 设备发放业务功能标识，allow表示发放成功，deny表示发放失败，设备发放使用此标识判断函数内业务功能执行与否
     *
     * @return status
     */
    public StatusEnum getStatus() {
        return status;
    }

    public void setStatus(StatusEnum status) {
        this.status = status;
    }

    public TdpFuncBody withContext(TdpFuncBodyContext context) {
        this.context = context;
        return this;
    }

    public TdpFuncBody withContext(Consumer<TdpFuncBodyContext> contextSetter) {
        if (this.context == null) {
            this.context = new TdpFuncBodyContext();
            contextSetter.accept(this.context);
        }

        return this;
    }

    /**
     * Get context
     *
     * @return context
     */
    public TdpFuncBodyContext getContext() {
        return context;
    }

    public void setContext(TdpFuncBodyContext context) {
        this.context = context;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TdpFuncBody tdpFuncBody = (TdpFuncBody) o;
        return Objects.equals(this.status, tdpFuncBody.status) &&
            Objects.equals(this.context, tdpFuncBody.context);
    }

    @Override
    public int hashCode() {
        return Objects.hash(status, context);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class TdpFuncBody {\n");
        sb.append("    status: ").append(toIndentedString(status)).append("\n");
        sb.append("    context: ").append(toIndentedString(context)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

