package com.huawei.demo.model;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.util.Objects;
import java.util.function.Consumer;

/**
 * TdpFuncResult
 */
public class TdpFuncResult {

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "statusCode")

    private Integer statusCode = 200;

    @JsonInclude(JsonInclude.Include.NON_NULL)
    @JsonProperty(value = "body")

    private TdpFuncBody body = null;

    public TdpFuncResult withStatusCode(Integer statusCode) {
        this.statusCode = statusCode;
        return this;
    }

    /**
     * 函数执行状态码，用于标识函数执行过程是否出现异常，遵循HTTP状态码含义。
     * minimum: 200
     * maximum: 599
     *
     * @return statusCode
     */
    public Integer getStatusCode() {
        return statusCode;
    }

    public void setStatusCode(Integer statusCode) {
        this.statusCode = statusCode;
    }

    public TdpFuncResult withBody(TdpFuncBody body) {
        this.body = body;
        return this;
    }

    public TdpFuncResult withBody(Consumer<TdpFuncBody> bodySetter) {
        if (this.body == null) {
            this.body = new TdpFuncBody();
            bodySetter.accept(this.body);
        }

        return this;
    }

    /**
     * Get body
     *
     * @return body
     */
    public TdpFuncBody getBody() {
        return body;
    }

    public void setBody(TdpFuncBody body) {
        this.body = body;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        TdpFuncResult tdpFuncResult = (TdpFuncResult) o;
        return Objects.equals(this.statusCode, tdpFuncResult.statusCode) &&
            Objects.equals(this.body, tdpFuncResult.body);
    }

    @Override
    public int hashCode() {
        return Objects.hash(statusCode, body);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class TdpFuncResult {\n");
        sb.append("    statusCode: ").append(toIndentedString(statusCode)).append("\n");
        sb.append("    body: ").append(toIndentedString(body)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

