package com.huawei.demo.model.api;

import com.fasterxml.jackson.annotation.JsonProperty;

import java.io.Serializable;
import java.util.Objects;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

/**
 * 接入点响应结构体。
 **/
public class AccessPointResp implements Serializable {
    private static final long serialVersionUID = 1L;

    @Size(max = 256, min = 1)
    @Valid
    @NotNull()
    @JsonProperty("access_point_id")
    private String accessPointId = null;

    @Size(max = 256, min = 1)
    @Valid
    @NotNull()
    @JsonProperty("access_point_name")
    private String accessPointName = null;

    @Size(max = 128, min = 1)
    @Valid
    @NotNull()
    @JsonProperty("region_id")
    private String regionId = null;

    public AccessPointResp() {
        super();
    }

    /**
     * 接入点id。
     * minLength: 1
     * maxLength: 256
     **/
    public String getAccessPointId() {
        return accessPointId;
    }

    public void setAccessPointId(String accessPointId_in) {
        this.accessPointId = accessPointId_in;
    }

    /**
     * 接入点名称。
     * minLength: 1
     * maxLength: 256
     **/
    public String getAccessPointName() {
        return accessPointName;
    }

    public void setAccessPointName(String accessPointName_in) {
        this.accessPointName = accessPointName_in;
    }

    /**
     * 华为云终端节点ID。节选自https://developer.huaweicloud.com/endpoint。
     * minLength: 1
     * maxLength: 128
     **/
    public String getRegionId() {
        return regionId;
    }

    public void setRegionId(String regionId_in) {
        this.regionId = regionId_in;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        AccessPointResp accessPointResp = (AccessPointResp) o;
        return Objects.equals(this.accessPointId,
            accessPointResp.accessPointId)
            && Objects.equals(this.accessPointName,
            accessPointResp.accessPointName)
            && Objects.equals(this.regionId,
            accessPointResp.regionId);
    }

    @Override
    public int hashCode() {
        return Objects.hash(accessPointId, accessPointName, regionId);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AccessPointResp { ");

        sb.append("  accessPointId: ").append(accessPointId).append(", ");
        sb.append("  accessPointName: ").append(accessPointName).append(", ");
        sb.append("  regionId: ").append(regionId).append(", ");
        sb.append("} ");
        return sb.toString();
    }
}
