package com.huawei.demo.model.api;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;

import java.io.Serializable;
import java.util.Objects;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;

@JsonIgnoreProperties(ignoreUnknown = true)
@JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
public class AllocateDeviceReq implements Serializable {
    private static final long serialVersionUID = 1L;

    @Pattern(regexp = "^[a-zA-Z0-9_-]{1,128}$")
    @Valid
    @JsonProperty("authorizing_domain_id")
    private String authorizingDomainId = null;

    @Size(max = 256, min = 1)
    @Valid
    @NotNull()
    @JsonProperty("access_point_id")
    private String accessPointId = null;

    @Pattern(regexp = "^[a-f0-9-]{1,36}$")
    @Valid
    @JsonProperty("product_id")
    private String productId = null;

    @Pattern(regexp = "^[a-zA-Z0-9_-]{1,64}$")
    @Valid
    @JsonProperty("region_id")
    private String regionId = null;

    @Size(max = 256, min = 1)
    @Valid
    @JsonProperty("app_id")
    private String appId = null;

    public AllocateDeviceReq() {
        super();
    }

    /**
     * 授权租户的账户ID
     * pattern: "^[a-zA-Z0-9_-]{1,128}$"
     **/
    public String getAuthorizingDomainId() {
        return authorizingDomainId;
    }

    public void setAuthorizingDomainId(String authorizingDomainId_in) {
        this.authorizingDomainId = authorizingDomainId_in;
    }

    /**
     * 接入点id。
     * minLength: 1
     * maxLength: 256
     **/
    public String getAccessPointId() {
        return accessPointId;
    }

    public void setAccessPointId(String accessPointId_in) {
        this.accessPointId = accessPointId_in;
    }

    /**
     * 产品ID，用于唯一标识一个产品，在物联网平台的SP Portal上导入产品模型后由平台分配获得。使用自定义策略场景需要填该字段，非自定义策略不用填该字段
     * pattern: "^[a-f0-9-]{1,36}$"
     **/
    public String getProductId() {
        return productId;
    }

    public void setProductId(String productId_in) {
        this.productId = productId_in;
    }

    /**
     * 区域ID，用于区分不同的区域。
     * pattern: "^[a-zA-Z0-9_-]{1,64}$"
     **/
    public String getRegionId() {
        return regionId;
    }

    public void setRegionId(String regionId_in) {
        this.regionId = regionId_in;
    }

    /**
     * 应用ID。此参数为非必选参数，用于兼容平台老用户存在多应用的场景。存在多应用的用户需要使用该接口时，可以携带该参数查询指定应用下的设备列表，不携带该参数则会查询该用户下所有设备列表。
     * minLength: 1
     * maxLength: 256
     **/
    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId_in) {
        this.appId = appId_in;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        AllocateDeviceReq allocateDeviceReq = (AllocateDeviceReq) o;
        return Objects.equals(this.authorizingDomainId,
            allocateDeviceReq.authorizingDomainId)
            && Objects.equals(this.accessPointId,
            allocateDeviceReq.accessPointId)
            && Objects.equals(this.productId,
            allocateDeviceReq.productId)
            && Objects.equals(this.regionId,
            allocateDeviceReq.regionId)
            && Objects.equals(this.appId,
            allocateDeviceReq.appId);
    }

    @Override
    public int hashCode() {
        return Objects.hash(authorizingDomainId
            , accessPointId
            , productId
            , regionId
            , appId);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AllocateDeviceReq { ");
        sb.append("  authorizingDomainId: ").append(authorizingDomainId).append(", ");
        sb.append("  accessPointId: ").append(accessPointId).append(", ");
        sb.append("  productId: ").append(productId).append(", ");
        sb.append("  regionId: ").append(regionId).append(", ");
        sb.append("  appId: ").append(appId).append(", ");
        sb.append("} ");
        return sb.toString();
    }
}
