package com.huawei.demo.model.api;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;

import java.io.Serializable;
import java.util.Objects;

import javax.validation.Valid;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;

/**
 * 设备信息中的发放信息结构体，携带设备发放专属的字段（接入点、发放类型、产品信息、引导状态、发放状态等）
 **/
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonSerialize(include = JsonSerialize.Inclusion.NON_NULL)
@JsonInclude(JsonInclude.Include.NON_NULL)
public class ProvisionInfoBaseResp implements Serializable {
    private static final long serialVersionUID = 1L;

    @Valid
    @JsonProperty("access_point")
    private AccessPointResp accessPoint = null;

    @Valid
    @JsonProperty("app_info")
    private ApplicationResp appInfo = null;

    @Size(max = 256, min = 0)
    @Pattern(regexp = "^[一-龥a-zA-Z0-9_-]*$")
    @Valid
    @JsonProperty("cert_name")
    private String certName = null;

    @Min(value = 0)
    @Max(value = 3)
    @Valid
    @JsonProperty("allocation_status")
    private Integer allocationStatus = null;

    @Pattern(regexp = "(base|certificates|functions|nearby|migrations)")
    @Valid
    @JsonProperty("allocation_strategy_type")
    private String allocationStrategyType = "base";

    @Min(value = 0)
    @Max(value = 864000)
    @Valid
    @JsonProperty("life_time")
    private Integer lifeTime = null;

    @Size(max = 65535, min = 1)
    @Valid
    @JsonProperty("init_config")
    private String initConfig = null;

    public ProvisionInfoBaseResp() {
        super();
    }

    /**
     * 发放区域。
     **/
    public AccessPointResp getAccessPoint() {
        return accessPoint;
    }

    public void setAccessPoint(AccessPointResp accessPoint_in) {
        this.accessPoint = accessPoint_in;
    }

    /**
     * 所属应用。
     **/
    public ApplicationResp getAppInfo() {
        return appInfo;
    }

    public void setAppInfo(ApplicationResp appInfo_in) {
        this.appInfo = appInfo_in;
    }

    /**
     * CA证书名称。设备认证类型为证书认证时返回。
     * minLength: 0
     * maxLength: 256
     * pattern: "^[一-龥a-zA-Z0-9_-]*$"
     **/
    public String getCertName() {
        return certName;
    }

    public void setCertName(String certName_in) {
        this.certName = certName_in;
    }

    /**
     * 设备发放状态。\n\n取值如下：\n- 0：成功；\n- 1：失败；\n- 2：发放中；\n- 3：未发放（默认）。
     * minimum: 0.0
     * maximum: 3.0
     **/
    public Integer getAllocationStatus() {
        return allocationStatus;
    }

    public void setAllocationStatus(Integer allocationStatus_in) {
        this.allocationStatus = allocationStatus_in;
    }

    /**
     * 策略类型。\n\n取值如下：\n- base：静态策略；\n- certificates：证书策略；\n- functions：自定义策略；\n- nearby：就近策略；\n- migrations: 指定迁移策略。
     * pattern: "(base|certificates|functions|nearby|migrations)"
     **/
    public String getAllocationStrategyType() {
        return allocationStrategyType;
    }

    public void setAllocationStrategyType(String allocationStrategyType_in) {
        this.allocationStrategyType = allocationStrategyType_in;
    }

    /**
     * LWM2M设备导入的默认生命周期。
     * minimum: 0.0
     * maximum: 864000.0
     **/
    public Integer getLifeTime() {
        return lifeTime;
    }

    public void setLifeTime(Integer lifeTime_in) {
        this.lifeTime = lifeTime_in;
    }

    /**
     * 设备的初始化配置。
     * minLength: 1
     * maxLength: 65535
     **/
    public String getInitConfig() {
        return initConfig;
    }

    public void setInitConfig(String initConfig_in) {
        this.initConfig = initConfig_in;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        ProvisionInfoBaseResp provisionInfoBaseResp = (ProvisionInfoBaseResp) o;
        return Objects.equals(this.accessPoint, provisionInfoBaseResp.accessPoint)
            && Objects.equals(this.appInfo, provisionInfoBaseResp.appInfo)
            && Objects.equals(this.certName, provisionInfoBaseResp.certName)
            && Objects.equals(this.allocationStatus, provisionInfoBaseResp.allocationStatus)
            && Objects.equals(this.allocationStrategyType, provisionInfoBaseResp.allocationStrategyType)
            && Objects.equals(this.lifeTime, provisionInfoBaseResp.lifeTime)
            && Objects.equals(this.initConfig, provisionInfoBaseResp.initConfig);
    }

    @Override
    public int hashCode() {
        return Objects.hash(accessPoint, appInfo, certName, allocationStatus, allocationStrategyType, lifeTime,
            initConfig);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ProvisionInfoBaseResp { ");

        sb.append("  accessPoint: ").append(accessPoint).append(", ");
        sb.append("  appInfo: ").append(appInfo).append(", ");
        sb.append("  certName: ").append(certName).append(", ");
        sb.append("  allocationStatus: ").append(allocationStatus).append(", ");
        sb.append("  allocationStrategyType: ").append(allocationStrategyType).append(", ");
        sb.append("  lifeTime: ").append(lifeTime).append(", ");
        sb.append("  initConfig: ").append(initConfig).append(", ");
        sb.append("} ");
        return sb.toString();
    }
}
